@@ -19,6 +19,7 @@ number nlRInit (long i);
 #include "kernel/ideals.h"
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <unistd.h>
 
 // send a number via a string s
 static char *send_number(char *s, number n)
@@ -63,7 +64,7 @@ static char * get_number(char *s, number *n)
   s+=SIZEOF_LONG;
   if (((*d)&1)==1) // immidiate number
   {
-    *n=(number)(*d); 
+    *n=(number)(*d);
   }
   else
   {
@@ -100,7 +101,7 @@ static long size_number(number n)
   }
   else
   {
-    if (n->s==3) 
+    if (n->s==3)
     {
       ll+=SIZEOF_LONG*2; /* n->s, mpz size */
       long l=mpz_size1(n->z);
@@ -209,6 +210,9 @@ ideal id_ChineseRemainder_0(ideal *xx, number *q, int rl, const ring r)
     return NULL;
   }
   int cpus=(int)(long)feOptValue(FE_OPT_CPUS);
+  if (cpus>=vspace::internals::MAX_PROCESS)
+    cpus=vspace::internals::MAX_PROCESS-1;
+  /* start no more than MAX_PROCESS-1 children */
   if ((cpus==1) || (2*cpus>=cnt))
     /* at least 2 polys for each process, or switch to seriell version */
     return id_ChineseRemainder(xx,q,rl,r);
@@ -295,7 +299,10 @@ ideal id_Farey_0(ideal x, number N, const ring r)
 {
   int cnt=IDELEMS(x)*x->nrows;
   int cpus=(int)(long)feOptValue(FE_OPT_CPUS);
-  if (2*cpus>=cnt) /* at least 2 polys for each process, 
+  if (cpus>=vspace::internals::MAX_PROCESS)
+    cpus=vspace::internals::MAX_PROCESS-1;
+  /* start no more than MAX_PROCESS-1 children */
+  if (2*cpus>=cnt) /* at least 2 polys for each process,
                      or switch to seriell version */
     return id_Farey(x,N,r);
   ideal result=idInit(cnt,x->rank);
